==> haskell-finite-typelits-0.2.0.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-finite-typelits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 finite-typelits
version:              0.2.0.1
visibility:           public
id:                   finite-typelits-0.2.0.1-GGRhRWS81wR3f2FV1N9OP4
key:                  finite-typelits-0.2.0.1-GGRhRWS81wR3f2FV1N9OP4
license:              BSD-3-Clause
maintainer:           mniip@mniip.com
author:               mniip
homepage:             https://github.com/mniip/finite-typelits
synopsis:
    A type inhabited by finitely many values, indexed by type-level naturals

description:
    A type inhabited by finitely many values, indexed by type-level naturals.

category:             Data
abi:                  c31cca3aaf9d982c0b9795fe71ae522f
exposed:              True
exposed-modules:
    Data.Finite Data.Finite.Integral Data.Finite.Internal
    Data.Finite.Internal.Integral

import-dirs:          /usr/lib/ghc-9.4.8/site-local/finite-typelits-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/finite-typelits-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/finite-typelits-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-finite-typelits
hs-libraries:         HSfinite-typelits-0.2.0.1-GGRhRWS81wR3f2FV1N9OP4
depends:
    base-4.17.2.1 deepseq-1.4.8.0 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-finite-typelits/html/finite-typelits.haddock

haddock-html:         /usr/share/doc/haskell-finite-typelits/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-finite-typelits-0.2.0.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-finite-typelits.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 finite-typelits
version:              0.2.0.1
visibility:           public
id:                   finite-typelits-0.2.0.1-DIZtN7PwLCeAqW6ytkbhhd
key:                  finite-typelits-0.2.0.1-DIZtN7PwLCeAqW6ytkbhhd
license:              BSD-3-Clause
maintainer:           mniip@mniip.com
author:               mniip
homepage:             https://github.com/mniip/finite-typelits
synopsis:
    A type inhabited by finitely many values, indexed by type-level naturals

description:
    A type inhabited by finitely many values, indexed by type-level naturals.

category:             Data
abi:                  104868181698b794a677148b368753b3
exposed:              True
exposed-modules:
    Data.Finite Data.Finite.Integral Data.Finite.Internal
    Data.Finite.Internal.Integral

import-dirs:          /usr/lib/ghc-9.4.8/site-local/finite-typelits-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/finite-typelits-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/finite-typelits-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-finite-typelits
hs-libraries:         HSfinite-typelits-0.2.0.1-DIZtN7PwLCeAqW6ytkbhhd
depends:
    base-4.17.2.1 deepseq-1.4.8.0 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    template-haskell-2.19.0.0

haddock-interfaces:
    /usr/share/doc/haskell-finite-typelits/html/finite-typelits.haddock

haddock-html:         /usr/share/doc/haskell-finite-typelits/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
